#
# spec file for package python-google-auth
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-google-auth
Version:        1.21.2
Release:        3.4.1
Summary:        Google Authentication Library
License:        Apache-2.0
URL:            https://github.com/GoogleCloudPlatform/google-auth-library-python
Source:         https://files.pythonhosted.org/packages/source/g/google-auth/google-auth-%{version}.tar.gz
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module cachetools >= 2.0.0}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module mock >= 3}
BuildRequires:  %{python_module oauth2client-gce}
BuildRequires:  %{python_module oauth2client}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pyasn1-modules >= 0.2.1}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest >= 4}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module rsa >= 3.1.4}
BuildRequires:  %{python_module setuptools >= 40.3.0}
BuildRequires:  %{python_module six >= 1.9.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cachetools >= 2.0.0
Requires:       python-pyasn1-modules >= 0.2.1
Requires:       python-rsa >= 3.1.4
Requires:       python-setuptools >= 40.3.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch
%python_subpackages

%description
This library simplifies using Google’s various server-to-server authentication mechanisms to access Google APIs.

%prep
%setup -q -n google-auth-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# skip tests that faild due to old mock on Leap
%pytest -k 'not (test_refresh_source_credentials or test_before_request or test_configure_mtls_channel_with_metadata or test_configure_mtls_channel_with_metadata or test_configure_mtls_channel_non_mtls)'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Wed Sep 23 2020 dmueller@suse.com
- update to 1.21.2:
  * migrate signBlob to iamcredentials.googleapis.com
* Tue Sep 15 2020 tchvatal@suse.com
- Skip tests that require too new mock package
* Thu Sep 10 2020 adrian.glaubitz@suse.com
- Update to 1.21.1
  * dummy commit to trigger a auto release (#597)
- from version 1.21.0
  * add GOOGLE_API_USE_CLIENT_CERTIFICATE support (#592)
- from version 1.20.1
  * reduce refresh clock skew to 10 seconds (#581)
  * set Content-Type header in the request to signBlob API
    to avoid Invalid JSON payload error (#439)
- from version 1.20.0
  * Add debug logging that can help with diagnosing auth lib. path (#473)
  * Show the transport exception that happened for GCE Metadata (#474)
  * **packaging:** add support for Python 3.8 (#569), closes (#568)
- from version 1.19.2
  * Revert "fix: migrate signBlob to iamcredentials.googleapis.com"  (#563)
- from version 1.19.1
  * don't add empty quota project  (#560)
- from version 1.19.0
  * add quota project to base credentials class (#546)
  * check 'iss' in `verify_oauth2_token` (#500)
  * migrate signBlob to iamcredentials.googleapis.com (#553)
  * remove 3.4 from supported versions list (#549)
- from version 1.18.0
  * make ``load_credentials_from_file`` a public method (#530)
  * no warning if quota_project_id is given (#537)
* Mon Jun 29 2020 sean.marlow@suse.com
- Add missing pyOpenSSL test dependency which is listed upstream.
* Thu Jun 18 2020 adrian.glaubitz@suse.com
- Update to 1.17.2
  + Bug Fixes
  * narrow acceptable RSA versions to maintain Python 2 compatability (#528)
- from version 1.17.1
  + Features
  * add quota_project_id to service accounts; add with_quota_project methods (#519)
- from version 1.16.1
  + Bug Fixes
  * fix impersonated cred exception doc (#521)
  * replace environment variable GCE_METADATA_ROOT with GCE_METADATA_HOST (#433)
- from version 1.16.0
  + Features
  * add helper func to for default encrypted cert (#514)
  + Bug Fixes
  * fix impersonated cred for gcloud (#516)
* Mon May 25 2020 info@paolostivanin.com
- Update to 1.15.0:
  * encrypted mtls private key support
  * signBytes for impersonated credentials
  * catch exceptions.RefreshError
  * support string type response.data
* Tue Apr 28 2020 tchvatal@suse.com
- Update to 1.14.1:
  * Many bugixes all around
- Remove no longer needed patch:
  * pytest5.patch
- Update the dependencies to match up setup.py and what upstream
  really requires
* Mon Jul 22 2019 tchvatal@suse.com
- Add patch to build with pytest5:
  * pytest5.patch
* Fri Mar 15 2019 tchvatal@suse.com
- Update to 1.6.3:
  * follow rfc 7515 : strip padding from JWS segments #324 (#324)
  * Add retry to _metadata.ping() (#323)
  * Announce deprecation of Python 2.7 (#311)
  * Link all the PRs in CHANGELOG (#307)
  * Automatically refresh impersonated credentials (#304)
  * Add google.auth.impersonated_credentials (#299)
  * Enable static type checking with pytype (#298)
  * Make classifiers in setup.py an array. (#280)
- Drop oauth-no-appengine.patch should not be needed
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Sep 12 2018 tbechtold@suse.com
- update to 1.5.1:
  - Fix check for error text on Python 3.7. (#278)
  - Use new Auth URIs. (#281)
  - Add code-of-conduct document. (#270)
  - Fix some typos in test_urllib3.py (#268)
  - Warn when using user credentials from the Cloud SDK (#266)
  - Add compute engine-based IDTokenCredentials (#236)
  - Corrected some typos (#265)
* Tue May 29 2018 tbechtold@suse.com
- update to 1.4.2:
  - Raise a helpful exception when trying to refresh credentials without
    a refresh token. (#262)
  - Fix links to README and CONTRIBUTING in docs/index.rst. (#260)
  - Fix a typo in credentials.py. (#256)
  - Use pytest instead of py.test per upstream recommendation,
    [#]dropthedot. (#255)
  - Fix typo on exemple of jwt usage (#245)
- Drop Flask from Requires. It is only needed for testing
* Tue May  8 2018 tchvatal@suse.com
- Add patch to not check for oauth appengine which we disable in
  openSUSE:
  * oauth-no-appengine.patch
* Mon May  7 2018 tchvatal@suse.com
- Fix fdupes call and run tests
* Mon May  7 2018 adrian.glaubitz@suse.com
- New upstream release (bsc#1088358)
  + Version 1.4.1
  - Added a check for the cryptography version before attempting to use it.
  + From version 1.4.0
  - Added `cryptography`-based RSA signer and verifier.
  - Added `google.oauth2.service_account.IDTokenCredentials`.
  - Improved documentation around ID Tokens
  + From version 1.3.0
  - Added ``google.oauth2.credentials.Credentials.from_authorized_user_file``.
  - Dropped direct pyasn1 dependency in favor of letting ``pyasn1-modules``
    specify the right version.
  - ``default()`` now checks for the project ID environment var before
    warning about missing project ID.
  - Fixed the docstrings for ``has_scopes()`` and ``with_scopes()``.
  - Fixed example in docstring for ``ReadOnlyScoped``.
  - Made ``transport.requests`` use timeouts and retries
    to improve reliability.
* Sun Nov 19 2017 mc@suse.com
- initial version 1.2.1
